@@ -25,11 +25,11 @@ class GroupSettingsDialog : public KGetSaveSizeDialog
 
         QSize sizeHint() const override;
 
-    private slots:
+    private Q_SLOTS:
         void save();
 
     private:
-        TransferGroupHandler* m_group;
+        TransferGroupHandler* m_group = nullptr;
         Ui::GroupSettingsDialog ui;
 
 };
